// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"

namespace Dawn {
  class Game;
  class Scene;
  class Camera;
  class RenderTarget;

  class RenderPipeline {
    public:
      /**
       * Creates a new RenderPipeline.
       */
      RenderPipeline();

      /**
       * Renders the game. This will render the current scene.
       * 
       * @param game Game to render.
       */
      void render(
        const std::shared_ptr<Game> game
      );

      /**
       * Renders a specific scene. This will render all cameras within the
       * scene.
       * 
       * @param game Game to render.
       * @param scene Scene to render.
       */
      void renderScene(
        const std::shared_ptr<Game> game,
        const std::shared_ptr<Scene> scene
      );

      /**
       * Renders a specific scene with a specific camera.
       * 
       * @param game Game to render.
       * @param scene Scene to render.
       * @param camera Camera to render.
       * @param renderTarget Render target to render to.
       */
      void renderSceneCamera(
        const std::shared_ptr<Game> game,
        const std::shared_ptr<Scene> scene,
        const std::shared_ptr<Camera> camera,
        const std::shared_ptr<RenderTarget> renderTarget
      );

      /**
       * Destroys the RenderPipeline.
       */
      virtual ~RenderPipeline();
  };
}