// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"

namespace Dawn {
  class SaveManager;

  struct SaveFile final {
    private:
      std::unordered_map<std::string, std::string> data;
      bool_t hasChanges = false;

    public:
      /**
       * Creates a new SaveFile.
       */
      SaveFile();

      /**
       * Returns true if the SaveFile has unsaved changes.
       * 
       * @return True if the SaveFile has changes.
       */
      bool_t doesSaveHaveChanges();

      /**
       * Returns true if the key exists.
       * 
       * @param key Key to check.
       * @return True if the key exists.
       */
      bool_t has(const std::string &key);

      /**
       * Returns the value of the key.
       * 
       * @param key Key to get the value of.
       * @return The value of the key.
       */
      template<typename T>
      T get(const std::string &key);

      /**
       * Sets the value of the key.
       * 
       * @param key Key to set the value of.
       * @param value Value to set the key to.
       */
      template<typename T>
      void set(const std::string &key, const T value);

      /**
       * Destroys the SaveFile.
       */
      virtual ~SaveFile();

      friend class SaveManager;
  };
}