// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"

namespace Dawn {
  class Easing final {
    public:
      /**
       * Linear easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t linear(float_t t);

      /**
       * Quadratic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeInQuad(float_t t);

      /**
       * Quadratic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeOutQuad(float_t t);

      /**
       * Quadratic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeInOutQuad(float_t t);

      /**
       * Cubic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeInCubic(float_t t);
      
      /**
       * Cubic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeOutCubic(float_t t);

      /**
       * Cubic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeInOutCubic(float_t t);

      /**
       * Quartic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeInQuart(float_t t);

      /**
       * Quartic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeOutQuart(float_t t);

      /**
       * Quartic easing function.
       * 
       * @param t Time value between 0 and 1.
       * @return Eased value.
       */
      static float_t easeInOutQuart(float_t t);
  };
}