// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "asset/AssetManager.hpp"
#include "loaders/TrueTypeLoader.hpp"

template<>
std::shared_ptr<TrueTypeTexture> AssetManager::get<TrueTypeTexture>(
  const std::string filename,
  const uint32_t fontSize
) {
  auto existing = this->getExisting<TrueTypeLoader>(filename);
  if(existing) {
    // Check pointer hasn't gone stale, if it has remove it and create new.
    auto texture = existing->getTexture(fontSize);
    if(texture) return texture;
    this->removeExisting(filename);
  }

  std::shared_ptr<TrueTypeLoader> loader = std::make_shared<TrueTypeLoader>(
    filename
  );
  pendingAssetLoaders.push_back(std::static_pointer_cast<AssetLoader>(loader));
  return loader->getTexture(fontSize);
}